{% extends "base.html" %}

{% block title %}
	Gas Contracts &raquo; {{g_contract.name}} &raquo; Batches
{% endblock %}

{% block nav %}
	<a href="/g_contracts">Gas Contracts</a> &raquo;
	<a href="/g_contracts/{{g_contract.id}}">{{g_contract.name}}</a> &raquo;
	Batches [<a href="/g_contracts/{{g_contract.id}}/add_batch">add</a>]
{% endblock %}

{% block content %}
	<div class="layer-section">
		<div class="section-content">
			<div class="section-data">
				<table class="DataTable widthAuto noMarginBottom">
					<thead>
						<tr>
							<th>Reference</th>
							<th>Description</th>
						</tr>
					</thead>
					<tbody>
						{% for g_batch in g_batches %}
							<tr>
								<td>
									<a href="/g_batches/{{g_batch.id}}">{{g_batch.reference}}</a>
								</td>
								<td>{{g_batch.description}}</td>
							</tr>
						{% endfor %}
					</tbody>
				</table>
			</div>
		</div>
	</div>
{% endblock %}
