{% extends "base.html" %}

{% block title %}
	&raquo; CSV Register Reads
{% endblock %}

{% block nav %}
	CSV Register Reads
{% endblock %}

{% block content %}
	<!-- Layer Section -->
	<div class="layer-section">
		<!-- Section Header -->
		<div class="section-header">
			<h2>Download</h2>	
		</div>
		<!-- End Section Header -->
		<!-- Section Content -->
		<div class="section-content">
			<div class="section-data">
				<div class="standardForm textWidthAuto">
					<form action="/reports/219">
						<fieldset>
							For {{input_text('months', 1, 2, 2)}} month(s) finishing at the
						 	end of {{input_date('end', init, resolution='month')}}
							<input type="submit" value="Download">
						</fieldset>

						<p>
							A register read has both a previous and present reading. A read
							will appear in the report if either the previous or present
							reading date falls within the reporting period. The reason is
						 	that it may be that a reading only appears as a previous reading
							(if the supply is new for example).
						</p>
					</form>
				</div>
			</div>
		</div>
		<!-- End Section Content -->
	</div>
	<!-- End Layer Section -->
{% endblock %}
