{% extends "base.html" %}

{% block title %}
	Gas Supplier Contracts
{% endblock %}

{% block nav %}
	Gas Supplier Contracts [<a href="/g_contracts/add">add</a>]
{% endblock %}

{% block content %}
	<div class="layer-section">
		<div class="section-header">
			<h2>Gas Contracts</h2>	
		</div>
		<div class="section-content">
			<div class="section-data">
				<table class="DataTable widthAuto noMarginBottom">
					<thead>
						<tr>
							<th>Name</th>
							<th>Start Date</th>
							<th>Finish Date</th>
						</tr>
					</thead>
					<tbody>
						{% for g_contract in contracts %}
							<tr>
								<td>
									<a
											href="/g_contracts/{{g_contract.id}}"
											>{{g_contract.name}}</a>
								</td>
								<td>
									{{g_contract.start_g_rate_script.start_date|hh_format}}
								</td>
								<td>
									{{g_contract.finish_g_rate_script.finish_date|hh_format}}
								</td>
							</tr>
						{% endfor %}
					</tbody>
				</table>
			</div>
		</div>
	</div>
{% endblock %}
