{% extends "base.html" %}

{% block title %}
	&raquo; System &raquo; Chains &raquo; {{paths[0][0][0]}}
{% endblock %}

{% block nav %}
	<a href="/system">System</a> &raquo;
	<a href="/system/chains">Chains</a> &raquo; {{paths[0][0][0]}}
{% endblock %}

{% block content %}
	<!-- Layer Section -->
	<div class="layer-section">
		<!-- Section Header -->
		<div class="section-header">
			<h2>Chain</h2>	
		</div>
		<!-- End Section Header -->

		<!-- Section Content -->
		<div class="section-content">
			<div class="section-data">
				<table>
					<tr>
						<th>Unreachable</th>
						<td>{{unreachable}}</td>
					</tr>
				</table>

				{% for chain in paths %}
				<table class="DataTable widthAuto">
					<caption>Chain</caption>
					<thead>
							<tr>
								<th>Id</th>
								<th>Type</th>
								<th>Value</th>
							</tr>
					</thead>
					<tbody>
						{% for obj_id, obj_typ, obj_val in chain %}
							<tr>
								<td>{{obj_id}}</td>
								<td>{{obj_typ}}</td>
								<td>{{obj_val}}</td>
							</tr>
						{% endfor %}
					</tbody>
				</table>
				{% endfor %}
			</div>
		</div>
	</div>
{% endblock %}
