{% extends "base.html" %}

{% block title %}
	&raquo; DC Contracts &raquo; {{ contract.name }} &raquo; Batches
{% endblock %}

{% block nav %}
	&raquo; <a href="/dc_contracts">DC Contracts</a> &raquo;
	<a href="/dc_contracts/{{contract.id}}">{{contract.name}}</a>
 	&raquo; Batches
	[<a href="/dc_contracts/{{contract.id}}/add_batch">add</a>]
{% endblock %}

{% block content %}
	<div class="layer-section">
		<div class="section-header">
			<h2>Batches</h2>
		</div>
		<div class="section-content">
			<div class="section-data">
				<table class="DataTable widthAuto noMarginBottom">
					<thead>
						<tr>
							<th>Reference</th>
							<th>Description</th>
						</tr>
					</thead>
					<tbody>
						{% for batch in batches %}
							<tr>
								<td>
									<a href="/dc_batches/{{batch.id}}">{{batch.reference}}</a>
								</td>
								<td>{{ batch.description }}</td>
							</tr>
						{% endfor %}
					</tbody>
				</table>
			</div>
		</div>
	</div>
{% endblock %}
