{% extends "base.html" %}

{% block title %}
	&raquo; Non-Core Contracts &raquo; {{ contract.name }} &raquo; Add Rate Script
{% endblock %}

{% block nav %}
	&raquo; <a href="/non_core_contracts">Non-Core Contracts</a> &raquo; 
	<a href="/non_core_contracts/{{contract.id}}">{{contract.name}}</a>
	&raquo; Add Rate Scripts
{% endblock %}

{% block content %}
<div class="layer-section">
	<div class="section-header">
		<h2>Add a rate script</h2>	
	</div>
	<div class="section-content">
		<div class="section-data">
			<div class="standardForm textWidthAuto">
				<form method="post">
					<fieldset>
						<input type="hidden" name="non_core_contract_id" value="{{contract.id}}">
						
						<fieldset>
							<legend>Start Date</legend>
							{{ input_date('start', initial_date) }}
						</fieldset>
						
						<input type="submit" value="Add">
					</fieldset>
				</form>
			</div>
		</div>
	</div>
</div>

	
{% endblock %}
