{% extends "base.html" %}

{% block title %}
	&raquo; DNOs &raquo; {{valid_mtc_llfc_ssc_pc.llfc.dno.dno_code}} &raquo;
	Valid MTC, LLFC, SSC, PC Combinations &raquo;
	{{valid_mtc_llfc_ssc_pc.mtc.code}}
	{{valid_mtc_llfc_ssc_pc.llfc.code}}
	{{valid_mtc_llfc_ssc_pc.ssc.code}}
	{{valid_mtc_llfc_ssc_pc.pc.code}}
{% endblock %}

{% block nav %}
	<a href="/dnos">DNOs</a> &raquo; 
	<a href="/dnos/{{valid_mtc_llfc_ssc_pc.llfc.dno.id}}"
		>{{valid_mtc_llfc_ssc_pc.llfc.dno.dno_code}}</a> &raquo; 
	<a href="/valid_mtc_llfc_ssc_pcs?dno_id={{valid_mtc_llfc_ssc_pc.llfc.dno.id}}"
		>Valid MTC, LLFC, SSC, PC Combinations</a> &raquo;
	{{valid_mtc_llfc_ssc_pc.mtc.code}}
	{{valid_mtc_llfc_ssc_pc.llfc.code}}
	{{valid_mtc_llfc_ssc_pc.ssc.code}}
	{{valid_mtc_llfc_ssc_pc.pc.code}}
{% endblock %}

{% block content %}
	<!-- Layer Section -->
	<div class="layer-section">
		<!-- Section Header -->
		<div class="section-header">
			<h2>{{llfc.description}}</h2>	
		</div>
		<!-- End Section Header -->
		<!-- Section Content -->
		<div class="section-content">
			<div class="section-data">
				<table class="DataTable widthAuto">
					<tr>
						<th>MTC Code</th>
						<td>{{valid_mtc_llfc_ssc_pc.mtc.code}}</td>
					</tr>
					<tr>
						<th>LLFC Code</th>
						<td>{{valid_mtc_llfc_ssc_pc.llfc.code}}</td>
					</tr>
					<tr>
						<th>SSC Code</th>
						<td>{{valid_mtc_llfc_ssc_pc.ssc.code}}</td>
					</tr>
					<tr>
						<th>PC Code</th>
						<td>{{valid_mtc_llfc_ssc_pc.pc.code}}</td>
					</tr>
					<tr>
						<th>Valid From</th>
						<td>{{valid_mtc_llfc_ssc_pc.valid_from|hh_format}}</td>
					</tr>
					<tr>
						<th>Valid To</th>
						<td>{{valid_mtc_llfc_ssc_pc.valid_to|hh_format}}</td>
					</tr>
				</table>
			</div>
		</div>
		<!-- End Section Content -->
	</div>
	<!-- End Layer Section -->
{% endblock %}
