{% extends "base.html" %}

{% block title %}
	&raquo; Report Downloads
{% endblock %}

{% block nav %}
	&raquo; Report Downloads
{% endblock %}

{% block content %}

<!-- Layer Section -->
<div class="layer-section">
	<!-- Section Header -->
	<div class="section-header">
		<h2>Report Files</h2>	
	</div>
	<!-- End Section Header -->
	<!-- Section Content -->
	<div class="section-content">
		<div class="section-data">
            
    		     
            
			<table class="DataTable widthAuto">
				<caption><a href="/downloads">Refresh page</a></caption>
				<thead>
					<tr>
						<th>Name</th>
						<th>Size</th>
						<th>Last Modified</th>
						<th>
						    <form method="post">
            					<fieldset>
            						<input type="submit" name="delete" value="Delete All">
            					</fieldset>
            				</form>
						</th>
					</tr>
				</thead>
				<tbody>
					{% for file in files %}
						<tr>
							<td>
								<a href="/downloads/{{file.name}}">{{file.name}}</a>
							</td>
							<td style="text-align: right;">
								{{"{:,}".format(file.size)}} B
							</td>
							<td>{{file.last_modified|hh_format}}</td>
							<td>
								<form
									method="post" action="/downloads/{{file.name}}">
									<fieldset style="border: none;">
										<input type="submit" name="delete" value="Delete">
									</fieldset>
								</form>
							</td>
						</tr>
					{% endfor %}
				</tbody>
			</table>
		</div>
		
	</div>
	<!-- End Section Content -->
</div>
<!-- End Layer Section -->
	
{% endblock %}
