{% extends "base.html" %}

{% block title %}
	&raquo; CSV Supplies Monthly Duration
{% endblock %}

{% block nav %}
	&raquo; CSV Supplies Monthly Duration
{% endblock %}

{% block content %}
<!-- Layer Section -->
<div class="layer-section">
	<!-- Section Header -->
	<div class="section-header">
		<h2>Download</h2>	
	</div>
	<!-- End Section Header -->
	<!-- Section Content -->
	<div class="section-content">
		<div class="section-data">
			<div class="standardForm textWidthAuto ">
				<form action="/reports/177">
					<fieldset>
						For {{input_text('months', 1, 2, 2)}}
						month(s) finishing at the end of
						{{input_date('end', init, resolution='month')}}
						<input type="submit" value="Download">
					</fieldset>
				</form>
			</div>
		</div>
	</div>
	<!-- End Section Content -->
</div>
<!-- End Layer Section -->


{% endblock %}
