{% extends "base.html" %}

{% block title %}
	&raquo; Bill Types
{% endblock %}

{% block nav %}
	&raquo; Bill Types
{% endblock %}

{% block content %}
<!-- Layer Section -->
<div class="layer-section">
	<!-- Section Header -->
	<div class="section-header">
		<h2>Bill Types</h2>	
	</div>
	<!-- End Section Header -->
	<!-- Section Content -->
	<div class="section-content">
		<div class="section-data">
			<table class="DataTable widthAuto">
				<thead>
					<tr>
						<th>Code</th>
						<th>Description</th>
					</tr>
				</thead>
				<tbody>
					{% for bill_type in bill_types %}
						<tr>
							<td>
								<a
										href="/bill_types/{{bill_type.id}}"
										>{{bill_type.code}}</a>
							</td>
							<td>{{bill_type.description}}</td>
						</tr>
					{% endfor %}
				</tbody>
			</table>
		</div>
	</div>
	<!-- End Section Content -->
</div>
<!-- End Layer Section -->

	
{% endblock %}
