{% extends "base.html" %}

{% block title %}
	&raquo; Supplier Contracts &raquo; {{supplier_rate_script.contract.name}} &raquo; 
 	Rate Scripts &raquo; {{supplier_rate_script.start_date|hh_format}} &raquo; Edit
{% endblock %}

{% block nav %}
	&raquo; <a href="/supplier_contracts">Supplier Contracts</a> &raquo; 
	<a href="/supplier_contracts/{{supplier_rate_script.contract.id}}">{{supplier_rate_script.contract.name}}</a> &raquo; 
	<a href="/supplier_rate_scripts/{{supplier_rate_script.id}}">Rate Script {{supplier_rate_script.start_date|hh_format}}</a>
 	&raquo; Edit
{% endblock %}

{% block content %}
	{% if request.method == 'GET' and request.values.delete %}

		<div class="layer-section">
			<div class="section-header">
				<h2>Are you sure you want to delete this rate script?</h2>	
			</div>
			<div class="section-content">
				<div class="section-data">
					<div class="standardForm">
						<form
								method="post"
								action="/supplier_rate_scripts/{{supplier_rate_script.id}}/edit"
								>
							<fieldset>
								<input type="submit" name="delete" value="Delete">
								<input
										type="reset" value="Cancel"
									 	onClick="window.location='/supplier_rate_scripts/{{supplier_rate_script.id}}/edit'">
							
							</fieldset>
						</form>
					</div>
				</div>
			</div>
		</div>
			

	{% else %}
	
		<div class="layer-section">
			<div class="section-header">
				<h2>Update Rate Script</h2>	
			</div>
			<div class="section-content">
				<div class="standardForm textWidthAuto">
					<form action="" method="post">
						<fieldset>
							<div class="section-data">
								<fieldset>
									<legend>Start date</legend>
									{{ input_date('start', supplier_rate_script.start_date) }}
								</fieldset>
							</div>
							<div class="section-data">
								<fieldset>
									<legend>Finish date</legend>
									<label>
										Ended?
										{{ input_checkbox(
											'has_finished',
										 	supplier_rate_script.finish_date != None) }}
									</label>
									{{ input_date('finish', supplier_rate_script.finish_date) }}
								</fieldset>
							</div>
							<div class="section-data">
								Script
								<br>
								{{ input_textarea(
									'script', supplier_rate_script.script, 40, 80,
								 	show_pos=True) }}
								<br>
								<input type="submit" value="Update">
							</div>
						</fieldset>
					</form>
				</div>
				{% if rate_script_example %}
					<div class="section-data">
						<br>
						<h4>Example</h4>
						<pre>{{rate_script_example}}</pre>
					</div>
				{% endif %}
			</div>
		</div>
		<div class="layer-section">
			<div class="section-header">
				<h2>Delete this Rate Script</h2>	
			</div>
			<div class="section-content">
				<div class="section-data">
					<div class="standardForm">
						<form>
							<fieldset>
								<input type="submit" name="delete" value="Delete">
							</fieldset>
						</form>
					</div>
				</div>
			</div>
		</div>
	{% endif %}
{% endblock %}
