{% extends "base.html" %}

{% block title %}
	&raquo; Energisation Statuses &raquo; {{energisation_status.code}}
{% endblock %}

{% block nav %}
	&raquo; <a href="/energisation_statuses">Energisation Statuses</a> &raquo;
	{{energisation_status.code}}
{% endblock %}

{% block content %}

	<!-- Layer Section -->
	<div class="layer-section">
		<!-- Section Header -->
		<div class="section-header">
			<h2>{{energisation_status.code}}</h2>	
		</div>
		<!-- End Section Header -->
		<!-- Section Content -->
		<div class="section-content">
			<div class="section-data">
				<table class="DataTable widthAuto">
					<tr>
						<th>Code</th>
						<td>{{energisation_status.code}}</td>
					</tr>
					<tr>
						<th>Description</th>
						<td>{{energisation_status.description}}</td>
					</tr>
				</table>
			</div>
		</div>
		<!-- End Section Content -->
	</div>
	<!-- End Layer Section -->
	
{% endblock %}
