{% extends "base.html" %}

{% block title %}
	&raquo; DNOs &raquo; {{llfc.dno.dno_code}} &raquo; LLFCs &raquo;
 	{{llfc.code}}
{% endblock %}

{% block nav %}
	<a href="/dnos">DNOs</a> &raquo; 
	<a href="/dnos/{{llfc.dno.id}}">{{llfc.dno.dno_code}}</a> &raquo; 
	<a href="/llfcs?dno_id={{llfc.dno.id}}">LLFCs</a> &raquo; {{llfc.code}}
	[<a href="/llfcs/{{llfc.id}}/edit">edit</a>]
{% endblock %}

{% block content %}
	<!-- Layer Section -->
	<div class="layer-section">
		<!-- Section Header -->
		<div class="section-header">
			<h2>{{llfc.description}}</h2>	
		</div>
		<!-- End Section Header -->
		<!-- Section Content -->
		<div class="section-content">
			<div class="section-data">
				<table class="DataTable widthAuto">
					<tr>
						<th>Code</th>
						<td>{{llfc.code}}</td>
					</tr>
					<tr>
						<th>Description</th>
						<td>{{llfc.description}}</td>
					</tr>
					<tr>
						<th>Voltage Level</th>
						<td>{{llfc.voltage_level.code}} - {{llfc.voltage_level.name}}</td>
					</tr>
					<tr>
						<th>Is Substation?</th>
						<td>{{llfc.is_substation}}</td>
					</tr>
					<tr>
						<th>Is Import?</th>
						<td>{{llfc.is_import}}</td>
					</tr>
					<tr>
						<th>Valid From</th>
						<td>{{llfc.valid_from|hh_format}}</td>
					</tr>
					<tr>
						<th>Valid To</th>
						<td>{{llfc.valid_to|hh_format}}</td>
					</tr>
					<tr>
						<th>Loss Adjustment Factors</th>
						<td>
							<a href="/lafs?llfc_id={{llfc.id}}&amp;year={{now.year}}&amp;month={{now.month}}">LAFs</a>
						</td>
					</tr>
				</table>
			</div>
		</div>
		<!-- End Section Content -->
	</div>
	<!-- End Layer Section -->
{% endblock %}
