{% extends "base.html" %}

{% block title %}
	Asset Comparison
{% endblock %}

{% block nav %}
	Asset Comparison
{% endblock %}

{% block content %}
	<!-- Layer Section -->
	<div class="layer-section">
		<div class="section-header">
			<h2>Comparison Against Asset Data</h2>	
		</div>
		<!-- Section Content -->
		<div class="section-content">
			<div class="section-data">
				<form enctype="multipart/form-data" method="post"
						action="/reports/asset_comparison">
					<fieldset>
						<input
								type="file" name="asset_file" size="45"
								value="{{request.values.asset_file}}">
						<br>
						<input type="submit" value="Compare">
					</fieldset>
				</form>
				<br>
				<p>
					This tool takes a spreadsheet of asset data and compares it against
					Chellow data and reports any inconsistencies. The spreadsheet can be
					downloaded from {{description}}.
				</p>
			</div>
		</div>
		<!-- End Section Content -->
	</div>
	<!-- End Layer Section -->                                      
{% endblock %}
