{% extends "base.html" %}

{% block title %}
	&raquo; MOP Contracts
{% endblock %}

{% block nav %}
	&raquo; MOP Contracts [<a href="/mop_contracts/add">add</a>]
{% endblock %}

{% block content %}
<div class="layer-section">
	<div class="section-header">
		<h2>MOP Contracts</h2>
	</div>
	<div class="section-content">
		<div class="section-data">
			<dviv class="DataTable">
				<table>
					<thead>
						<tr>
							<th>Name</th>
							<th>Start Date</th>
							<th>Finish Date</th>
							<th>MOP</th>
						</tr>
					</thead>
					<tbody>
						{% for contract in mop_contracts %}
							<tr>
								<td>
									<a href="/mop_contracts/{{contract.id}}">{{contract.name}}</a>
								</td>
								<td>{{contract.start_rate_script.start_date|hh_format }}</td>
								<td>{{contract.finish_rate_script.finish_date|hh_format}}</td>
								<td>
									<a href="/parties/{{contract.party.id}}">{{contract.party.name}}</a>
								</td>
							</tr>
						{% endfor %}
					</tbody>
				</table>
			</div>
		</div>
	</div>
</div>

	
{% endblock %}
