{% extends "base.html" %}

{% block title %}
	&raquo; DC Contracts
{% endblock %}

{% block nav %}
	&raquo; DC Contracts [<a href="/dc_contracts/add">add</a>]
{% endblock %}

{% block content %}
<div class="layer-section">
	<div class="section-header">
		<h2>DC Contracts</h2>
	</div>
	<div class="section-content">
		<div class="section-data">
			<div class="noWrap-md">
				<table class="DataTable widthAuto noMarginBottom">
					<thead>
						<tr>
							<th>Name</th>
							<th>Start Date</th>
							<th>Finish Date</th>
							<th>DC</th>
						</tr>
					</thead>
					<tbody>
						{% for contract in dc_contracts %}
							<tr>
								<td>
									<a href="/dc_contracts/{{contract.id}}">{{contract.name}}</a>
								</td>
								<td>{{ contract.start_rate_script.start_date|hh_format }}</td>
								<td>{{ contract.finish_rate_script.finish_date|hh_format }}</td>
								<td>
									<a href="/parties/{{contract.party.id}}">{{contract.party.name}}</a>
								</td>
							</tr>
						{% endfor %}
					</tbody>
				</table>
			</div>
		</div>
	</div>
</div>


	
{% endblock %}
