{% extends "base.html" %}

{% block title %}
	Gas Contracts &raquo; {{g_contract.name}} &raquo; Add Rate Script
{% endblock %}

{% block nav %}
	<a href="/g_contracts">Gas Contracts</a> &raquo;
	<a href="/g_contracts/{{g_contract.id}}">{{g_contract.name}}</a> &raquo;
 	Add Rate Script
{% endblock %}

{% block content %}
	<div class="layer-section">
		<div class="section-content">
			<div class="section-data">
				<div class="standardForm textWidthAuto">
					<form
					 		action="/g_contracts/{{g_contract.id}}/add_rate_script"
						 	method="post">
						<fieldset>
							<legend>Add a rate script</legend>
							<br>
							<fieldset>
								<legend>Start Date</legend>
								{{input_date('start', initial_date)}}
							</fieldset>
							<br>
							<br>
							<input type="submit" value="Add">
						</fieldset>
					</form>
				</div>
			</div>
		</div>
	</div>
{% endblock %}
