{% extends "base.html" %}

{% block title %}
	&raquo; Gas Supplies &raquo; {{g_supply.id}} &raquo; Notes &raquo; Add
{% endblock %}

{% block nav %}
	&raquo; <a href="/g_supplies">Gas Supplies</a>  &raquo;
	<a href="/g_supplies/{{g_supply.id}}">{{g_supply.id}}</a>  &raquo;
	<a href="/g_supplies/{{g_supply.id}}/notes">Notes</a>  &raquo; Add
{% endblock %}

{% block content %}
	<div class="layer-section">
		<div class="section-header">
			<h2>Note</h2>
		</div>
		<div class="section-content">
			<div class="section-data">
				<div class="standardForm">
					<div class="row">
						<div class="col-sm-6">
							<form
									method="post"
									action="/g_supplies/{{g_supply.id}}/notes/add">
								<input type="hidden" name="g_supply_id" value="{{g_supply.id}}">
								Category {{input_text('category')}}
								<br>
								Important?{{input_checkbox('is_important')}}
								<br>
								{{input_textarea('body', '', 30, 80)}}
							<input type="submit" value="Add">
							</form>	
						</div>
					</div>
				</div>
			</div>
		</div>
	</div>
{% endblock %}
