{% extends "base.html" %}

{% block title %}
	DNs &raquo; {{g_dn.code}}
{% endblock %}

{% block nav %}
	<a href="/g_dns">DNs</a> &raquo; {{g_dn.code}}
{% endblock %}

{% block content %}
	<div class="layer-section">
		<div class="section-content">
			<div class="section-data">
				<table class="DataTable widthAuto noMarginBottom">
					<tr>
						<th>Code</th>
						<td>{{g_dn.code}}</td>
					</tr>
					<tr>
						<th>Name</th>
						<td>{{g_dn.name}}</td>
					</tr>
				</table>
				<br>

				<h4>LDZs</h4>
				<ul>
					{% for g_ldz in g_ldzs %}
						<li>
							<a href="/g_ldzs/{{g_ldz.id}}">{{g_ldz.code}}</a>
						</li>
					{% endfor %}
				</ul>
			</div>
		</div>
	</div>
{% endblock %}
