{% extends "base.html" %}

{% block title %}
	&raquo; GSP Groups &raquo; {{gsp_group.code}}
{% endblock %}

{% block nav %}
	&raquo; <a href="/gsp_groups">GSP Groups</a> &raquo; {{gsp_group.code}}
{% endblock %}

{% block content %}
<!-- Layer Section -->
<div class="layer-section">
	<!-- Section Header -->
	<div class="section-header">
		<h2>{{gsp_group.code}}</h2>	
	</div>
	<!-- End Section Header -->
	<!-- Section Content -->
	<div class="section-content">
		<div class="section-data">
			<table class="DataTable widthAuto">
				<tr>
					<th>Code</th>
					<td>{{gsp_group.code}}</td>
				</tr>
				<tr>
						<th>Description</th>
						<td>{{gsp_group.description}}</td>
				</tr>
			</table>
		</div>
	</div>
	<!-- End Section Content -->
</div>
<!-- End Layer Section -->

	
{% endblock %}
