{% extends "base.html" %}

{% block title %}
	&raquo; Non-core Contracts &raquo; {{rate_script.contract.name}} &raquo; Rate Scripts &raquo; 
	{{ rate_script.start_date|hh_format }} &raquo; Edit
{% endblock %}

{% block nav %}
	&raquo; <a href="/non_core_contracts">Non-core Contracts</a> &raquo; 
	<a href="/non_core_contracts/{{rate_script.contract.id}}">{{rate_script.contract.name}}</a> &raquo; 
	<a href="/non_core_rate_scripts/{{rate_script.id}}">{{rate_script.start_date|hh_format}}</a>
 	&raquo; Edit
{% endblock %}

{% block content %}
	{% if request.method == 'GET' and request.values.delete %}
	<div class="layer-section">
		<div class="section-header">
			<h2>Are you sure you want to delete this rate script?</h2>	
		</div>
		<div class="section-content">
			<div class="section-data">
				<div class="standardForm">
					<form method="post">
						<fieldset>
							<input type="hidden" name="rate_script_id" value="{{rate_script.id}}">
							<input type="submit" name="delete" value="Delete" />
							<input type="reset" value="Cancel" onClick="window.location='/non_core_rate_scripts/{{rate_script.id}}/edit'" />
						</fieldset>
					</form>
				</div>
			</div>
		</div>
	</div>
			
	{% else %}
	
	<div class="layer-section">
		<div class="section-header">
			<h2>Update Rate Script</h2>	
		</div>
		<div class="section-content">
			<div class="standardForm textWidthAuto">
				<form method="post">
					<fieldset>
						<input type="hidden" name="rate_script_id" value="{{rate_script.id}}">
						<div class="section-data">
							<fieldset>
								<legend>Start date</legend>
								{{ input_date('start', rate_script.start_date) }}
							</fieldset>
						</div>
						<div class="section-data">
							<fieldset>
								<legend>Finish date</legend>
								<label>
									Ended?
								 	{{input_checkbox('has_finished', rate_script.finish_date != None)}}
								</label>
								{{ input_date('finish', rate_script.finish_date) }}
							</fieldset>
						</div>
						<div class="section-data">
							Script
							</br>
							{{ input_textarea('script', rate_script.script, 40, 80) }}
							</br>
							<input type="submit" value="Update">
						</div>							
					</fieldset>
				</form>
			</div>
		</div>
	</div>
	<div class="layer-section">
		<div class="section-header">
			<h2>Delete this Rate Script</h2>	
		</div>
		<div class="section-content">
			<div class="section-data">
				<form>
					<fieldset>
						<input type="hidden" name="rate_script_id" value="{{rate_script.id}}">
						<input type="submit" name="delete" value="Delete">
					</fieldset>
				</form>
			</div>
		</div>
	</div>
		
	{% endif %}
{% endblock %}
